==> lorcana-data-js-0.6.0-sources.jar: jsMain/eu/codlab/lorcana/resources/Resources.kt <==
package eu.codlab.lorcana.resources

import dev.icerock.moko.graphics.Color
import dev.icerock.moko.resources.AssetResource
import dev.icerock.moko.resources.ColorResource
import dev.icerock.moko.resources.FileResource
import dev.icerock.moko.resources.FontResource
import dev.icerock.moko.resources.ImageResource
import dev.icerock.moko.resources.PluralsResource
import dev.icerock.moko.resources.ResourceContainer
import dev.icerock.moko.resources.StringResource
import kotlin.String
import kotlin.collections.List

public actual object Resources {
  private val contentHash: String = "68cca0dd0f8fdeb38977ddb0e4633e2e"

  public actual object strings : ResourceContainer<StringResource> {
    public override fun values(): List<StringResource> = listOf()
  }

  public actual object plurals : ResourceContainer<PluralsResource> {
    public override fun values(): List<PluralsResource> = listOf()
  }

  public actual object images : ResourceContainer<ImageResource> {
    public override fun values(): List<ImageResource> = listOf()
  }

  public actual object fonts : ResourceContainer<FontResource> {
    public override fun values(): List<FontResource> = listOf()
  }

  public actual object files : ResourceContainer<FileResource> {
    public actual val abilities: FileResource = FileResource(fileUrl =
        js("require(\"files/abilities.yml\")") as String)

    public actual val classifications: FileResource = FileResource(fileUrl =
        js("require(\"files/classifications.yml\")") as String)

    public actual val configuration: FileResource = FileResource(fileUrl =
        js("require(\"files/configuration.yml\")") as String)

    public actual val franchises: FileResource = FileResource(fileUrl =
        js("require(\"files/franchises.yml\")") as String)

    public actual val iti: FileResource = FileResource(fileUrl = js("require(\"files/iti.yml\")") as
        String)

    public actual val placeholders: FileResource = FileResource(fileUrl =
        js("require(\"files/placeholders.yml\")") as String)

    public actual val rotf: FileResource = FileResource(fileUrl = js("require(\"files/rotf.yml\")")
        as String)

    public actual val tfc: FileResource = FileResource(fileUrl = js("require(\"files/tfc.yml\")") as
        String)

    public override fun values(): List<FileResource> = listOf(abilities, classifications,
        configuration, franchises, iti, placeholders, rotf, tfc)
  }

  public actual object colors : ResourceContainer<ColorResource> {
    public override fun values(): List<ColorResource> = listOf()
  }

  public actual object assets : ResourceContainer<AssetResource> {
    public override fun values(): List<AssetResource> = listOf()
  }
}

==> lorcana-data-js-0.8.0-sources.jar: jsMain/eu/codlab/lorcana/resources/Resources.kt <==
package eu.codlab.lorcana.resources

import dev.icerock.moko.graphics.Color
import dev.icerock.moko.resources.AssetResource
import dev.icerock.moko.resources.ColorResource
import dev.icerock.moko.resources.FileResource
import dev.icerock.moko.resources.FontResource
import dev.icerock.moko.resources.ImageResource
import dev.icerock.moko.resources.PluralsResource
import dev.icerock.moko.resources.ResourceContainer
import dev.icerock.moko.resources.StringResource
import kotlin.String
import kotlin.collections.List

public actual object Resources {
  private val contentHash: String = "debd8415be200e58061d223360678d3b"

  public actual object strings : ResourceContainer<StringResource> {
    public override fun values(): List<StringResource> = listOf()
  }

  public actual object plurals : ResourceContainer<PluralsResource> {
    public override fun values(): List<PluralsResource> = listOf()
  }

  public actual object images : ResourceContainer<ImageResource> {
    public override fun values(): List<ImageResource> = listOf()
  }

  public actual object fonts : ResourceContainer<FontResource> {
    public override fun values(): List<FontResource> = listOf()
  }

  public actual object files : ResourceContainer<FileResource> {
    public actual val abilities: FileResource = FileResource(fileUrl =
        js("require(\"files/abilities.yml\")") as String)

    public actual val classifications: FileResource = FileResource(fileUrl =
        js("require(\"files/classifications.yml\")") as String)

    public actual val configuration: FileResource = FileResource(fileUrl =
        js("require(\"files/configuration.yml\")") as String)

    public actual val franchises: FileResource = FileResource(fileUrl =
        js("require(\"files/franchises.yml\")") as String)

    public actual val iti: FileResource = FileResource(fileUrl = js("require(\"files/iti.yml\")") as
        String)

    public actual val placeholders: FileResource = FileResource(fileUrl =
        js("require(\"files/placeholders.yml\")") as String)

    public actual val rotf: FileResource = FileResource(fileUrl = js("require(\"files/rotf.yml\")")
        as String)

    public actual val tfc: FileResource = FileResource(fileUrl = js("require(\"files/tfc.yml\")") as
        String)

    public actual val urr: FileResource = FileResource(fileUrl = js("require(\"files/urr.yml\")") as
        String)

    public override fun values(): List<FileResource> = listOf(abilities, classifications,
        configuration, franchises, iti, placeholders, rotf, tfc, urr)
  }

  public actual object colors : ResourceContainer<ColorResource> {
    public override fun values(): List<ColorResource> = listOf()
  }

  public actual object assets : ResourceContainer<AssetResource> {
    public override fun values(): List<AssetResource> = listOf()
  }
}
